PCB Environment: ActionSet Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions
ActionSet Class Reference

## Public Member Functions
void | init (ActionSpace &, Action::Index first, Action::Index last)
void | init (ActionSpace &, const std::set< Action::Index > *=0)
const std::vector< Action::Index > | actions () const
uint | size () const
void | clear ()
void | insert (Action::Index)
void | remove (Action::Index)
ActionSpace * | space () const

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/RL/ActionSpace.hpp